@@ -3,55 +3,31 @@
 
 /* macros for various libc functions you can change for embedded targets */
 #ifndef XMALLOC
-   #if !defined(LTC_NO_PROTOTYPES) && defined(malloc)
-   #define LTC_NO_PROTOTYPES
-   #endif
 #define XMALLOC  malloc
 #endif
 #ifndef XREALLOC
-   #if !defined(LTC_NO_PROTOTYPES) && defined(realloc)
-   #define LTC_NO_PROTOTYPES
-   #endif
 #define XREALLOC realloc
 #endif
 #ifndef XCALLOC
-   #if !defined(LTC_NO_PROTOTYPES) && defined(calloc)
-   #define LTC_NO_PROTOTYPES
-   #endif
 #define XCALLOC  calloc
 #endif
 #ifndef XFREE
-   #if !defined(LTC_NO_PROTOTYPES) && defined(free)
-   #define LTC_NO_PROTOTYPES
-   #endif
 #define XFREE    free
 #endif
 
 #ifndef XMEMSET
-   #if !defined(LTC_NO_PROTOTYPES) && defined(memset)
-   #define LTC_NO_PROTOTYPES
-   #endif
 #define XMEMSET  memset
 #endif
 #ifndef XMEMCPY
-   #if !defined(LTC_NO_PROTOTYPES) && defined(memcpy)
-   #define LTC_NO_PROTOTYPES
-   #endif
 #define XMEMCPY  memcpy
 #endif
 #ifndef XMEMCMP
-   #if !defined(LTC_NO_PROTOTYPES) && defined(memcmp)
-   #define LTC_NO_PROTOTYPES
-   #endif
 #define XMEMCMP  memcmp
 #endif
 #ifndef XMEM_NEQ
 #define XMEM_NEQ  mem_neq
 #endif
 #ifndef XSTRCMP
-   #if !defined(LTC_NO_PROTOTYPES) && defined(strcmp)
-   #define LTC_NO_PROTOTYPES
-   #endif
 #define XSTRCMP strcmp
 #endif
 
@@ -63,12 +39,15 @@
 #endif
 
 #ifndef XQSORT
-   #if !defined(LTC_NO_PROTOTYPES) && defined(qsort)
-   #define LTC_NO_PROTOTYPES
-   #endif
 #define XQSORT qsort
 #endif
 
+#if ( defined(malloc) || defined(realloc) || defined(calloc) || defined(free) || \
+      defined(memset) || defined(memcpy) || defined(memcmp) || defined(strcmp) || \
+      defined(clock) || defined(qsort) ) && !defined(LTC_NO_PROTOTYPES)
+#define LTC_NO_PROTOTYPES
+#endif
+
 /* shortcut to disable automatic inclusion */
 #if defined LTC_NOTHING && !defined LTC_EASY
   #define LTC_NO_MATH
